==> tinkerforge-java-bindings_2.1.31.tar.xz: tinkerforge-java-bindings-2.1.31/src/main/java/com/tinkerforge/BrickDaemon.java <==
/*
 * Copyright (C) 2012-2014, 2020 Matthias Bolte <matthias@tinkerforge.com>
 * Copyright (C) 2011-2012 Olaf Lüke <olaf@tinkerforge.com>
 *
 * Redistribution and use in source and binary forms of this file,
 * with or without modification, are permitted. See the Creative
 * Commons Zero (CC0 1.0) License for more details.
 */

package com.tinkerforge;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

class BrickDaemon extends Device {
	public final static byte FUNCTION_GET_AUTHENTICATION_NONCE = (byte)1;
	public final static byte FUNCTION_AUTHENTICATE = (byte)2;

	public BrickDaemon(String uid, IPConnection ipcon) {
		super(uid, ipcon);

		apiVersion[0] = 2;
		apiVersion[1] = 0;
		apiVersion[2] = 0;

		responseExpected[IPConnection.unsignedByte(FUNCTION_GET_AUTHENTICATION_NONCE)] = RESPONSE_EXPECTED_FLAG_ALWAYS_TRUE;
		responseExpected[IPConnection.unsignedByte(FUNCTION_AUTHENTICATE)] = RESPONSE_EXPECTED_FLAG_TRUE;

		ipcon.addDevice(this);
	}

	public byte[] getAuthenticationNonce() throws TinkerforgeException {
		ByteBuffer bb = ipcon.createRequestPacket((byte)8, FUNCTION_GET_AUTHENTICATION_NONCE, this);

		byte[] response = sendRequest(bb.array(), 12);

		bb = ByteBuffer.wrap(response, 8, response.length - 8);
		bb.order(ByteOrder.LITTLE_ENDIAN);

		byte[] server_nonce = new byte[4];

		for (int i = 0; i < 4; i++) {
			server_nonce[i] = bb.get();
		}

		return server_nonce;
	}

	public void authenticate(byte[] client_nonce, byte[] digest) throws TinkerforgeException {
		ByteBuffer bb = ipcon.createRequestPacket((byte)32, FUNCTION_AUTHENTICATE, this);

		for (int i = 0; i < 4; i++) {
			bb.put(client_nonce[i]);
		}

		for (int i = 0; i < 20; i++) {
			bb.put(digest[i]);
		}

		sendRequest(bb.array(), 0);
	}

	public Identity getIdentity() throws TinkerforgeException {
		return null;
	}
}

==> tinkerforge-java-bindings_2.1.32.tar.xz: tinkerforge-java-bindings-2.1.32/src/main/java/com/tinkerforge/BrickDaemon.java <==
/*
 * Copyright (C) 2012-2014, 2020 Matthias Bolte <matthias@tinkerforge.com>
 * Copyright (C) 2011-2012 Olaf Lüke <olaf@tinkerforge.com>
 *
 * Redistribution and use in source and binary forms of this file,
 * with or without modification, are permitted. See the Creative
 * Commons Zero (CC0 1.0) License for more details.
 */

package com.tinkerforge;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

class BrickDaemon extends Device {
	public static final byte FUNCTION_GET_AUTHENTICATION_NONCE = (byte)1;
	public static final byte FUNCTION_AUTHENTICATE = (byte)2;

	public BrickDaemon(String uid, IPConnection ipcon) {
		super(uid, ipcon);

		apiVersion[0] = 2;
		apiVersion[1] = 0;
		apiVersion[2] = 0;

		responseExpected[IPConnection.unsignedByte(FUNCTION_GET_AUTHENTICATION_NONCE)] = RESPONSE_EXPECTED_FLAG_ALWAYS_TRUE;
		responseExpected[IPConnection.unsignedByte(FUNCTION_AUTHENTICATE)] = RESPONSE_EXPECTED_FLAG_TRUE;

		ipcon.addDevice(this);
	}

	public byte[] getAuthenticationNonce() throws TinkerforgeException {
		ByteBuffer bb = ipcon.createRequestPacket((byte)8, FUNCTION_GET_AUTHENTICATION_NONCE, this);

		byte[] response = sendRequest(bb.array(), 12);

		bb = ByteBuffer.wrap(response, 8, response.length - 8);
		bb.order(ByteOrder.LITTLE_ENDIAN);

		byte[] server_nonce = new byte[4];

		for (int i = 0; i < 4; i++) {
			server_nonce[i] = bb.get();
		}

		return server_nonce;
	}

	public void authenticate(byte[] client_nonce, byte[] digest) throws TinkerforgeException {
		ByteBuffer bb = ipcon.createRequestPacket((byte)32, FUNCTION_AUTHENTICATE, this);

		for (int i = 0; i < 4; i++) {
			bb.put(client_nonce[i]);
		}

		for (int i = 0; i < 20; i++) {
			bb.put(digest[i]);
		}

		sendRequest(bb.array(), 0);
	}

	public Identity getIdentity() throws TinkerforgeException {
		return null;
	}
}
